==> haskell-zlib-0.6.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-zlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: zlib
version: 0.6.2
id: zlib-0.6.2-FRkEyCRDCMJ4V7FViKOnGY
key: zlib-0.6.2-FRkEyCRDCMJ4V7FViKOnGY
license: BSD3
copyright: (c) 2006-2016 Duncan Coutts
maintainer: Duncan Coutts <duncan@community.haskell.org>
synopsis: Compression and decompression in the gzip and zlib formats
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the
    <https://en.wikipedia.org/wiki/Zlib zlib C library>
    so it has high performance. It supports the \"zlib\",
    \"gzip\" and \"raw\" compression formats.
    .
    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full zlib feature set.
category: Codec
author: Duncan Coutts <duncan@community.haskell.org>
exposed: True
indefinite: False
exposed-modules:
    Codec.Compression.GZip Codec.Compression.Zlib
    Codec.Compression.Zlib.Internal Codec.Compression.Zlib.Raw
hidden-modules: Codec.Compression.Zlib.Stream
abi: 0435506582323b785ad7538064910d9e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/zlib-0.6.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/zlib-0.6.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/zlib-0.6.2
hs-libraries: HSzlib-0.6.2-FRkEyCRDCMJ4V7FViKOnGY
extra-libraries:
    z
includes:
    zlib.h
depends:
    base-4.10.1.0 bytestring-0.10.8.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
haddock-interfaces: /usr/share/doc/haskell-zlib/html/zlib.haddock
haddock-html: /usr/share/doc/haskell-zlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zlib-0.6.2.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-zlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: zlib
version: 0.6.2.1
id: zlib-0.6.2.1-Aknvu72a6qHHNTLcHtkXd
key: zlib-0.6.2.1-Aknvu72a6qHHNTLcHtkXd
license: BSD-3-Clause
copyright: (c) 2006-2016 Duncan Coutts
maintainer: Duncan Coutts <duncan@community.haskell.org>
author: Duncan Coutts <duncan@community.haskell.org>
synopsis: Compression and decompression in the gzip and zlib formats
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the
    <https://en.wikipedia.org/wiki/Zlib zlib C library>
    so it has high performance. It supports the \"zlib\",
    \"gzip\" and \"raw\" compression formats.
    .
    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full zlib feature set.
category: Codec
abi: 481b24e221a3ce22ab9a31fcfb385580
exposed: True
exposed-modules:
    Codec.Compression.GZip Codec.Compression.Zlib
    Codec.Compression.Zlib.Internal Codec.Compression.Zlib.Raw
hidden-modules: Codec.Compression.Zlib.Stream
import-dirs: /usr/lib/ghc-8.6.5/site-local/zlib-0.6.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/zlib-0.6.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/zlib-0.6.2.1
hs-libraries: HSzlib-0.6.2.1-Aknvu72a6qHHNTLcHtkXd
extra-libraries:
    z
includes:
    zlib.h
depends:
    base-4.12.0.0 bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-zlib/html/zlib.haddock
haddock-html: /usr/share/doc/haskell-zlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
